#!/usr/bin/env python

from nes.nc_projections.default_nes import Nes

class PointsNes(Nes):
    """

    Attributes
    ----------
    _var_dim : tuple
        Tuple with the name of the Y and X dimensions for the variables.
        ('lat', 'lon') for a regular latitude-longitude projection.
    _lat_dim : tuple
        Tuple with the name of the dimensions of the Latitude values.
        ('lat',) for a regular latitude-longitude projection.
    _lon_dim : tuple
        Tuple with the name of the dimensions of the Longitude values.
        ('lon',) for a regular latitude-longitude projection.
    """
    def __init__(self, comm=None, path=None, info=False, dataset=None, xarray=False, parallel_method='Y',
                 avoid_first_hours=0, avoid_last_hours=0, first_level=0, last_level=None, create_nes=False, 
                 **kwargs):
        """
        Initialize the PointsNes class

        Parameters
        ----------
        comm: MPI.COMM
            Path to the CSV file that contains all the information.
        path: str
            Path to the NetCDF to initialize the object
        info: bool
            Indicates if you want to get reading/writing info
        dataset: Dataset
            NetCDF4-python Dataset to initialize the class
        xarray: bool:
            (Not working) Indicates if you want to use xarray as default
        parallel_method : str
            Indicates the parallelization method that you want. Default over Y axis
            accepted values: ['Y', 'T']
        avoid_first_hours : int
            Number of hours to remove from first time steps.
        avoid_last_hours : int
            Number of hours to remove from last time steps.
        """
        super(PointsNes, self).__init__(comm=comm, path=path, info=info, dataset=dataset,
                                        xarray=xarray, parallel_method=parallel_method,
                                        avoid_first_hours=avoid_first_hours, avoid_last_hours=avoid_last_hours,
                                        first_level=first_level, last_level=last_level, create_nes=create_nes,
                                        **kwargs)

        if create_nes:
            self._lat, self._lon = self._create_centroids(**kwargs)

        self._var_dim = ('lat', 'lon')
        self._lat_dim = ('lat',)
        self._lon_dim = ('lon',)

    def _create_dimensions(self, netcdf):
        """
        Create the 'lat', 'lon' dimensions and the super dimensions ('lev', 'time').

        Parameters
        ----------
        netcdf : Dataset
            NetCDF object.
        """
        super(PointsNes, self)._create_dimensions(netcdf)

        netcdf.createDimension('lon', len(self._lon['data']))
        netcdf.createDimension('lat', len(self._lat['data']))

        return None

    def _create_centroids(self, **kwargs):
        """
        Calculate center latitudes and longitudes from points.

        Parameters
        ----------
        netcdf : Dataset
            NetCDF object.
        """
        # Calculate center latitudes
        self.center_lats = kwargs['lat']

        # Calculate center longitudes
        self.center_lons = kwargs['lon']

        return {'data': self.center_lats}, {'data': self.center_lons}